@@ -85,7 +85,9 @@
 #' 
 #' @examples
 #' \dontrun{
-#' par(mfrow=c(2,2))
+#' set.seed(1)
+#' par(mfrow = c(2, 2))
+#' 
 #' x = rweibullgpd(1000)
 #' xx = seq(-1, 6, 0.01)
 #' hist(x, breaks = 100, freq = FALSE, xlim = c(-1, 6))
@@ -120,17 +122,17 @@ dweibullgpd <- function(x, wshape = 1, wscale = 1, u = qweibull(0.9, wshape, wsc
   xi = 0, phiu = TRUE, log = FALSE) {
   
   # Check properties of inputs
-  check.quant(x, allowmiss = TRUE, allowinf = TRUE)
-  check.posparam(param = wshape, allowvec = TRUE)
-  check.posparam(param = wscale, allowvec = TRUE)
-  check.posparam(param = u, allowvec = TRUE) # threshold also positive for Weibull
-  check.posparam(param = sigmau, allowvec = TRUE)
-  check.param(param = xi, allowvec = TRUE)
+  check.quant(x, allowna = TRUE, allowinf = TRUE)
+  check.posparam(wshape, allowvec = TRUE)
+  check.posparam(wscale, allowvec = TRUE)
+  check.posparam(u, allowvec = TRUE)
+  check.posparam(sigmau, allowvec = TRUE)
+  check.param(xi, allowvec = TRUE)
   check.phiu(phiu, allowvec = TRUE)
-  check.logic(logicarg = log)
+  check.logic(log)
 
   n = check.inputn(c(length(x), length(wshape), length(wscale),
-    length(u), length(sigmau), length(xi), length(phiu)))
+    length(u), length(sigmau), length(xi), length(phiu)), allowscalar = TRUE)
 
   if (any(is.infinite(x))) warning("infinite quantiles set to NA")
 
@@ -176,17 +178,17 @@ pweibullgpd <- function(q, wshape = 1, wscale = 1, u = qweibull(0.9, wshape, wsc
   xi = 0, phiu = TRUE, lower.tail = TRUE) {
 
   # Check properties of inputs
-  check.quant(q, allowmiss = TRUE, allowinf = TRUE)
-  check.posparam(param = wshape, allowvec = TRUE)
-  check.posparam(param = wscale, allowvec = TRUE)
-  check.posparam(param = u, allowvec = TRUE)
-  check.posparam(param = sigmau, allowvec = TRUE)
-  check.param(param = xi, allowvec = TRUE)
+  check.quant(q, allowna = TRUE, allowinf = TRUE)
+  check.posparam(wshape, allowvec = TRUE)
+  check.posparam(wscale, allowvec = TRUE)
+  check.posparam(u, allowvec = TRUE)
+  check.posparam(sigmau, allowvec = TRUE)
+  check.param(xi, allowvec = TRUE)
   check.phiu(phiu, allowvec = TRUE)
-  check.logic(logicarg = lower.tail)
+  check.logic(lower.tail)
 
   n = check.inputn(c(length(q), length(wshape), length(wscale),
-    length(u), length(sigmau), length(xi), length(phiu)))
+    length(u), length(sigmau), length(xi), length(phiu)), allowscalar = TRUE)
 
   if (any(is.infinite(q))) warning("infinite quantiles set to NA")
 
@@ -232,17 +234,17 @@ qweibullgpd <- function(p, wshape = 1, wscale = 1, u = qweibull(0.9, wshape, wsc
   xi = 0, phiu = TRUE, lower.tail = TRUE) {
 
   # Check properties of inputs
-  check.prob(p, allowmiss = TRUE)
-  check.posparam(param = wshape, allowvec = TRUE)
-  check.posparam(param = wscale, allowvec = TRUE)
-  check.posparam(param = u, allowvec = TRUE)
-  check.posparam(param = sigmau, allowvec = TRUE)
-  check.param(param = xi, allowvec = TRUE)
+  check.prob(p, allowna = TRUE)
+  check.posparam(wshape, allowvec = TRUE)
+  check.posparam(wscale, allowvec = TRUE)
+  check.posparam(u, allowvec = TRUE)
+  check.posparam(sigmau, allowvec = TRUE)
+  check.param(xi, allowvec = TRUE)
   check.phiu(phiu, allowvec = TRUE)
-  check.logic(logicarg = lower.tail)
+  check.logic(lower.tail)
 
   n = check.inputn(c(length(p), length(wshape), length(wscale),
-    length(u), length(sigmau), length(xi), length(phiu)))
+    length(u), length(sigmau), length(xi), length(phiu)), allowscalar = TRUE)
 
   if (!lower.tail) p = 1 - p
 
@@ -285,14 +287,15 @@ rweibullgpd <- function(n = 1, wshape = 1, wscale = 1, u = qweibull(0.9, wshape,
 
   # Check properties of inputs
   check.n(n)
-  check.param(param = wshape, allowvec = TRUE)
-  check.posparam(param = wscale, allowvec = TRUE)
-  check.posparam(param = u, allowvec = TRUE)
-  check.posparam(param = sigmau, allowvec = TRUE)
-  check.param(param = xi, allowvec = TRUE)
+  check.posparam(wshape, allowvec = TRUE)
+  check.posparam(wscale, allowvec = TRUE)
+  check.posparam(u, allowvec = TRUE)
+  check.posparam(sigmau, allowvec = TRUE)
+  check.param(xi, allowvec = TRUE)
   check.phiu(phiu, allowvec = TRUE)
 
-  n = check.inputn(c(n, length(wshape), length(wscale), length(u), length(sigmau), length(xi), length(phiu)))
+  n = check.inputn(c(n, length(wshape), length(wscale), length(u), length(sigmau), length(xi), length(phiu)),
+                   allowscalar = TRUE)
 
   if (any(xi == 1)) stop("shape cannot be 1")
 
