@@ -375,7 +375,7 @@ lweibullgpdcon <- function(x, wshape = 1, wscale = 1, u = qweibull(0.9, wshape,
     
     syu = 1 + xi * (xu - u) / sigmau  
   
-    if ((min(syu) <= 0) | (sigmau <= 0) | (du < .Machine$double.eps) | (phiu <= 0) | (phiu >= 1)) {
+    if ((min(syu) <= 0) | (sigmau <= 0) | (du < .Machine$double.eps) | (phiu <= 0) | (phiu >= 1) | (pu <= 0) | (pu >= 1)) {
       l = -Inf
     } else { 
       l = lgpd(xu, u, sigmau, xi, phiu)
@@ -426,7 +426,7 @@ nlweibullgpdcon <- function(pvector, x, phiu = TRUE, finitelik = FALSE) {
 # Weibull bulk with GPD for upper tail with continuity at threshold
 # designed for sapply to loop over vector of thresholds (hence u is first input)
 profluweibullgpdcon <- function(u, pvector, x, phiu = TRUE, method = "BFGS",
-  control = list(maxit = 10000), finitelik = FALSE, ...) {
+  control = list(maxit = 10000), finitelik = TRUE, ...) {
 
   np = 4 # maximum number of parameters
   
